@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,7 +66,7 @@ public enum TemplateErrorMessage implements OXErrorMessage {
     private String help;
     private String message;
     
-    public static TemplateExceptionFactory EXCEPTIONS = new TemplateExceptionFactory();
+    public static final TemplateExceptionFactory EXCEPTIONS = new TemplateExceptionFactory();
     
     private TemplateErrorMessage(final Category category, final int errorCode, final String help, final String message) {
         this.category = category;
