@@ -55,9 +55,7 @@ import junit.framework.TestCase;
 import com.openexchange.config.SimConfigurationService;
 import com.openexchange.exceptions.StringComponent;
 import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.session.Session;
 import com.openexchange.sim.SimBuilder;
 import com.openexchange.templating.impl.OXFolderHelper;
 import com.openexchange.templating.impl.OXInfostoreHelper;
